@@ -10,6 +10,7 @@
 #' @return A dataframe of participation data, optionally merged with play by play
 #'
 #' @examples
+#' \dontshow{.for_cran()}
 #' \donttest{
 #' try({ # prevents cran errors
 #'   load_participation(seasons = 2020, include_pbp = TRUE)
@@ -51,9 +52,11 @@ load_participation <- function(seasons = most_recent_season(),
     by.x = c("nflverse_game_id","play_id"),
     by.y = c("game_id","play_id"))
 
-  pbp_participation <- make_nflverse_data(pbp_participation,
-                     nflverse_type = "play-by-play participation",
-                     nflverse_timestamp = attr(participation,"nflverse_timestamp"))
+  pbp_participation <- make_nflverse_data(
+    pbp_participation,
+    nflverse_type = "play-by-play participation",
+    nflverse_timestamp = attr(participation, "nflverse_timestamp")
+  )
 
   return(pbp_participation)
 }
