@@ -2,7 +2,7 @@
 #'
 #' A helper function to choose the most recent season available for a given dataset
 #'
-#' @param roster a TRUE/FALSE flag: if TRUE, returns the current year if March 1st or later. if FALSE, returns the current year if September 1st or later. Otherwise returns current year minus 1.
+#' @param roster a TRUE/FALSE flag: if TRUE, returns the current year if March 15th or later. if FALSE, returns the current year if September 1st or later. Otherwise returns current year minus 1.
 #'
 #'
 #' @rdname latest_season
@@ -13,9 +13,11 @@ most_recent_season <- function(roster = FALSE) {
   today <- Sys.Date()
   current_year <- as.integer(format(today, format = "%Y"))
   current_month <- as.integer(format(today, format = "%m"))
+  current_day <- as.integer(format(today, format = "%d"))
 
   if ((isFALSE(roster) && current_month >= 9) ||
-      (isTRUE(roster) && current_month >= 3)) {
+      (isTRUE(roster) && current_month == 3 && current_day >= 15) ||
+      (isTRUE(roster) && current_month > 3 )) {
 
     return(current_year)
   }
